#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-tls
version:              0.3.5.3
visibility:           public
id:                   http-client-tls-0.3.5.3-1EuJcCGFPgBHafkDNjffQC
key:                  http-client-tls-0.3.5.3-1EuJcCGFPgBHafkDNjffQC
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  4cf62d8b47f48e50728f4f53c7a8bb46
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-8.10.5/site-local/http-client-tls-0.3.5.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/http-client-tls-0.3.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/http-client-tls-0.3.5.3
hs-libraries:         HShttp-client-tls-0.3.5.3-1EuJcCGFPgBHafkDNjffQC
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    connection-0.3.1-ADJpwCmobBsDFPJVx1SRC3 containers-0.6.4.1
    cryptonite-0.29-KSQcZnQaH5M3lIm9Vzc7YS
    data-default-class-0.1.2.0-9cFfQKP7sucLLfD3ZZyiPI exceptions-0.10.4
    http-client-0.7.8-C6JWYZrbeBCPAdb6EpQD6
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    memory-0.16.0-E1gXzMJzgEcJ8QhI9dLs6S
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M
    network-uri-2.6.4.1-4m8gp52oIfHLdE9VhQrWxs text-1.2.4.1
    tls-1.5.5-3PUcwYgzKPF3oXwCgpwp46 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

